==> state-use-6.0.4.tgz: package/lib/esm/index.test.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.promise.js";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { renderHook, act } from '@testing-library/react-hooks';
import { define } from './index';
var async = {
  default: function _default() {
    return {
      state: 'default'
    };
  },
  loading: function loading() {
    return {
      state: 'loading'
    };
  },
  success: function success(r) {
    return {
      state: 'success',
      response: r
    };
  },
  failure: function failure(e) {
    return {
      state: 'failure',
      error: e
    };
  }
};
test('should update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook = renderHook(function (props) {
    return state.use(function (s) {
      return s.a + props.delta;
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook.result,
      rerender = _renderHook.rerender; // update state.


  act(function () {
    state.update(function (ctx) {
      ctx.state.a++;
    });
    state.update(function (ctx) {
      ctx.state.a++;
    });
  });
  expect(result.current).toBe(4);
  expect(result.all).toHaveLength(2); // update deps.

  rerender({
    delta: 2
  });
  expect(result.current).toBe(5);
  expect(result.all).toHaveLength(3);
});
test('shouldn\'t update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook2 = renderHook(function (props) {
    return state.use(function (s) {
      return [s.a + props.delta];
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook2.result,
      rerender = _renderHook2.rerender; // no change state.


  var current = result.current;
  act(function () {
    state.update(function (ctx) {
      ctx.state.a = 1;
    });
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(1); // no change deps.

  rerender({
    delta: 1
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(2);
});
test('async success', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
  var state, _renderHook3, result;

  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          state = define();
          state.setup({
            num: async.default()
          });
          _renderHook3 = renderHook(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook3.result;
          _context3.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
            return _regeneratorRuntime.wrap(function _callee2$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(ctx) {
                      return _regeneratorRuntime.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context.prev = 1;
                              _context.t0 = async;
                              _context.next = 5;
                              return wait(100).then(function () {
                                return 100;
                              });

                            case 5:
                              _context.t1 = _context.sent;
                              ctx.state.num = _context.t0.success.call(_context.t0, _context.t1);
                              _context.next = 12;
                              break;

                            case 9:
                              _context.prev = 9;
                              _context.t2 = _context["catch"](1);
                              ctx.state.num = async.failure(_context.t2);

                            case 12:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context2.stop();
                }
              }
            }, _callee2);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.success(100)
          }]);

        case 6:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));
test('async failure', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
  var state, _renderHook4, result;

  return _regeneratorRuntime.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          state = define();
          state.setup({
            num: async.default()
          });
          _renderHook4 = renderHook(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook4.result;
          _context6.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
            return _regeneratorRuntime.wrap(function _callee5$(_context5) {
              while (1) {
                switch (_context5.prev = _context5.next) {
                  case 0:
                    _context5.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4(ctx) {
                      return _regeneratorRuntime.wrap(function _callee4$(_context4) {
                        while (1) {
                          switch (_context4.prev = _context4.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context4.prev = 1;
                              _context4.t0 = async;
                              _context4.next = 5;
                              return wait(100).then(function () {
                                return Promise.reject(100);
                              });

                            case 5:
                              _context4.t1 = _context4.sent;
                              ctx.state.num = _context4.t0.success.call(_context4.t0, _context4.t1);
                              _context4.next = 12;
                              break;

                            case 9:
                              _context4.prev = 9;
                              _context4.t2 = _context4["catch"](1);
                              ctx.state.num = async.failure(_context4.t2);

                            case 12:
                            case "end":
                              return _context4.stop();
                          }
                        }
                      }, _callee4, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context5.stop();
                }
              }
            }, _callee5);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.failure(100)
          }]);

        case 6:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6);
})));
test('nested update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook5 = renderHook(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook5.result;

  act(function () {
    state.update(function (ctx) {
      ctx.state.a++;
      state.update(function (ctx) {
        ctx.state.a++;
      });
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('nested async update', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
  var state, _renderHook6, result;

  return _regeneratorRuntime.wrap(function _callee10$(_context10) {
    while (1) {
      switch (_context10.prev = _context10.next) {
        case 0:
          state = define();
          state.setup({
            a: 1
          });
          _renderHook6 = renderHook(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook6.result;
          _context10.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
            return _regeneratorRuntime.wrap(function _callee9$(_context9) {
              while (1) {
                switch (_context9.prev = _context9.next) {
                  case 0:
                    _context9.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8(ctx) {
                      return _regeneratorRuntime.wrap(function _callee8$(_context8) {
                        while (1) {
                          switch (_context8.prev = _context8.next) {
                            case 0:
                              ctx.state.a++;
                              _context8.next = 3;
                              return wait(100).then(function () {
                                return ctx.state.a + 1;
                              });

                            case 3:
                              ctx.state.a = _context8.sent;
                              _context8.next = 6;
                              return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7(ctx) {
                                return _regeneratorRuntime.wrap(function _callee7$(_context7) {
                                  while (1) {
                                    switch (_context7.prev = _context7.next) {
                                      case 0:
                                        ctx.state.a++;
                                        _context7.next = 3;
                                        return wait(100).then(function () {
                                          return ctx.state.a + 1;
                                        });

                                      case 3:
                                        ctx.state.a = _context7.sent;
                                        state.update(function (ctx) {
                                          ctx.state.a++;
                                        });

                                      case 5:
                                      case "end":
                                        return _context7.stop();
                                    }
                                  }
                                }, _callee7);
                              }));

                            case 6:
                            case "end":
                              return _context8.stop();
                          }
                        }
                      }, _callee8);
                    }));

                  case 2:
                  case "end":
                    return _context9.stop();
                }
              }
            }, _callee9);
          })));

        case 5:
          expect(result.all).toEqual([1, 2, 4, 6]);

        case 6:
        case "end":
          return _context10.stop();
      }
    }
  }, _callee10);
})));
test('revoked draft should raise error', function (done) {
  var state = define();
  state.setup({
    a: 1
  });
  state.update(function (ctx) {
    var draft = ctx.state;
    draft.a++;
    setTimeout(function () {
      expect(function () {
        draft.a++;
      }).toThrow();
      done();
    }, 100);
  });
});

var wait = function wait(timeout) {
  return new Promise(function (resolve) {
    return setTimeout(resolve, timeout);
  });
};

==> state-use-6.0.7.tgz: package/lib/esm/index.test.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import "core-js/modules/es.object.to-string.js";
import "core-js/modules/es.promise.js";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { renderHook, act } from '@testing-library/react-hooks';
import { define } from './index';
var async = {
  default: function _default() {
    return {
      state: 'default'
    };
  },
  loading: function loading() {
    return {
      state: 'loading'
    };
  },
  success: function success(r) {
    return {
      state: 'success',
      response: r
    };
  },
  failure: function failure(e) {
    return {
      state: 'failure',
      error: e
    };
  }
};
test('should update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook = renderHook(function (props) {
    return state.use(function (s) {
      return s.a + props.delta;
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook.result,
      rerender = _renderHook.rerender; // update state.


  act(function () {
    state.update(function (ctx) {
      ctx.state.a++;
    });
    state.update(function (ctx) {
      ctx.state.a++;
    });
  });
  expect(result.current).toBe(4);
  expect(result.all).toHaveLength(2); // update deps.

  rerender({
    delta: 2
  });
  expect(result.current).toBe(5);
  expect(result.all).toHaveLength(3);
});
test('shouldn\'t update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook2 = renderHook(function (props) {
    return state.use(function (s) {
      return [s.a + props.delta];
    }, [props.delta]);
  }, {
    initialProps: {
      delta: 1
    }
  }),
      result = _renderHook2.result,
      rerender = _renderHook2.rerender; // no change state.


  var current = result.current;
  act(function () {
    state.update(function (ctx) {
      ctx.state.a = 1;
    });
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(1); // no change deps.

  rerender({
    delta: 1
  });
  expect(result.current).toBe(current);
  expect(result.all).toHaveLength(2);
});
test('async success', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
  var state, _renderHook3, result;

  return _regeneratorRuntime.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          state = define();
          state.setup({
            num: async.default()
          });
          _renderHook3 = renderHook(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook3.result;
          _context3.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
            return _regeneratorRuntime.wrap(function _callee2$(_context2) {
              while (1) {
                switch (_context2.prev = _context2.next) {
                  case 0:
                    _context2.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(ctx) {
                      return _regeneratorRuntime.wrap(function _callee$(_context) {
                        while (1) {
                          switch (_context.prev = _context.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context.prev = 1;
                              _context.t0 = async;
                              _context.next = 5;
                              return wait(100).then(function () {
                                return 100;
                              });

                            case 5:
                              _context.t1 = _context.sent;
                              ctx.state.num = _context.t0.success.call(_context.t0, _context.t1);
                              _context.next = 12;
                              break;

                            case 9:
                              _context.prev = 9;
                              _context.t2 = _context["catch"](1);
                              ctx.state.num = async.failure(_context.t2);

                            case 12:
                            case "end":
                              return _context.stop();
                          }
                        }
                      }, _callee, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context2.stop();
                }
              }
            }, _callee2);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.success(100)
          }]);

        case 6:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3);
})));
test('async failure', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
  var state, _renderHook4, result;

  return _regeneratorRuntime.wrap(function _callee6$(_context6) {
    while (1) {
      switch (_context6.prev = _context6.next) {
        case 0:
          state = define();
          state.setup({
            num: async.default()
          });
          _renderHook4 = renderHook(function () {
            return state.use(function (s) {
              return s;
            });
          }), result = _renderHook4.result;
          _context6.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
            return _regeneratorRuntime.wrap(function _callee5$(_context5) {
              while (1) {
                switch (_context5.prev = _context5.next) {
                  case 0:
                    _context5.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4(ctx) {
                      return _regeneratorRuntime.wrap(function _callee4$(_context4) {
                        while (1) {
                          switch (_context4.prev = _context4.next) {
                            case 0:
                              ctx.state.num = async.loading();
                              _context4.prev = 1;
                              _context4.t0 = async;
                              _context4.next = 5;
                              return wait(100).then(function () {
                                return Promise.reject(100);
                              });

                            case 5:
                              _context4.t1 = _context4.sent;
                              ctx.state.num = _context4.t0.success.call(_context4.t0, _context4.t1);
                              _context4.next = 12;
                              break;

                            case 9:
                              _context4.prev = 9;
                              _context4.t2 = _context4["catch"](1);
                              ctx.state.num = async.failure(_context4.t2);

                            case 12:
                            case "end":
                              return _context4.stop();
                          }
                        }
                      }, _callee4, null, [[1, 9]]);
                    }));

                  case 2:
                  case "end":
                    return _context5.stop();
                }
              }
            }, _callee5);
          })));

        case 5:
          expect(result.all).toEqual([{
            num: async.default()
          }, {
            num: async.loading()
          }, {
            num: async.failure(100)
          }]);

        case 6:
        case "end":
          return _context6.stop();
      }
    }
  }, _callee6);
})));
test('nested update', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook5 = renderHook(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook5.result;

  act(function () {
    state.update(function (ctx) {
      ctx.state.a++;
      state.update(function (ctx) {
        ctx.state.a++;
      });
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('merge synchronous context', function () {
  var state = define();
  state.setup({
    a: 1
  });

  var _renderHook6 = renderHook(function () {
    return state.use(function (s) {
      return s.a;
    });
  }),
      result = _renderHook6.result;

  act(function () {
    state.update(function (ctx) {
      var s = ctx.state;
      state.update(function () {
        s.a++;
      });
      s.a++;
    });
  });
  expect(result.current).toEqual(3);
  expect(result.all).toHaveLength(2);
});
test('nested async update', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
  var state, _renderHook7, result;

  return _regeneratorRuntime.wrap(function _callee10$(_context10) {
    while (1) {
      switch (_context10.prev = _context10.next) {
        case 0:
          state = define();
          state.setup({
            a: 1
          });
          _renderHook7 = renderHook(function () {
            return state.use(function (s) {
              return s.a;
            });
          }), result = _renderHook7.result;
          _context10.next = 5;
          return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
            return _regeneratorRuntime.wrap(function _callee9$(_context9) {
              while (1) {
                switch (_context9.prev = _context9.next) {
                  case 0:
                    _context9.next = 2;
                    return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8(ctx) {
                      return _regeneratorRuntime.wrap(function _callee8$(_context8) {
                        while (1) {
                          switch (_context8.prev = _context8.next) {
                            case 0:
                              ctx.state.a++;
                              _context8.next = 3;
                              return wait(100).then(function () {
                                return ctx.state.a + 1;
                              });

                            case 3:
                              ctx.state.a = _context8.sent;
                              _context8.next = 6;
                              return state.update( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7(ctx) {
                                return _regeneratorRuntime.wrap(function _callee7$(_context7) {
                                  while (1) {
                                    switch (_context7.prev = _context7.next) {
                                      case 0:
                                        ctx.state.a++;
                                        _context7.next = 3;
                                        return wait(100).then(function () {
                                          return ctx.state.a + 1;
                                        });

                                      case 3:
                                        ctx.state.a = _context7.sent;
                                        state.update(function (ctx) {
                                          ctx.state.a++;
                                        });

                                      case 5:
                                      case "end":
                                        return _context7.stop();
                                    }
                                  }
                                }, _callee7);
                              }));

                            case 6:
                            case "end":
                              return _context8.stop();
                          }
                        }
                      }, _callee8);
                    }));

                  case 2:
                  case "end":
                    return _context9.stop();
                }
              }
            }, _callee9);
          })));

        case 5:
          expect(result.all).toEqual([1, 2, 4, 6]);

        case 6:
        case "end":
          return _context10.stop();
      }
    }
  }, _callee10);
})));
test('revoked draft should raise error', function (done) {
  var state = define();
  state.setup({
    a: 1
  });
  state.update(function (ctx) {
    var draft = ctx.state;
    draft.a++;
    setTimeout(function () {
      expect(function () {
        draft.a++;
      }).toThrow();
      done();
    }, 100);
  });
});

var wait = function wait(timeout) {
  return new Promise(function (resolve) {
    return setTimeout(resolve, timeout);
  });
};
